==> side_menu_v1.3.1.zip: lib/Controller/CssController.php <==
<?php
/**
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace OCA\SideMenu\Controller;

use OCP\AppFramework\Controller;
use OCP\AppFramework\Http\TemplateResponse;
use OCP\AppFramework\Http\Response;
use OCP\IConfig;
use OCP\IRequest;

class CssController extends Controller
{

    /** @var \OCP\IConfig */
    protected $config;

    /**
     * @param string $appName
     * @param IRequest $request
     * @param IConfig $config
     */
    public function __construct($appName, IRequest $request, IConfig $config)
    {
        parent::__construct($appName, $request);

        $this->config = $config;
    }

    /**
     * @NoAdminRequired
     * @NoCSRFRequired
     * @PublicPage
     *
     * @return Response
     */
    public function stylesheet()
    {
        $requestUri = $this->request->server['REQUEST_URI'];
        $assetsRoot = str_replace('/index.php', '', $requestUri);
        $assetsRoot = preg_replace('#apps/side_menu/.*#s', 'apps/side_menu', $assetsRoot);

        $parameters = [
            'vars' => [
                'background-color' => $this->config->getAppValue('side_menu', 'background-color', '#333333'),
                'current-app-background-color' => $this->config->getAppValue('side_menu', 'current-app-background-color', '#444444'),
                'text-color' => $this->config->getAppValue('side_menu', 'text-color', '#FFFFFF'),
                'opener' => $this->config->getAppValue('side_menu', 'opener', 'side-menu-opener'),
            ],
            'display-logo' => (bool) $this->config->getAppValue('side_menu', 'display-logo', 1),
            'assetsRoot' => $assetsRoot,
        ];

        $response = new TemplateResponse('side_menu', 'css/stylesheet', $parameters, 'blank');
        $response->addHeader('Content-Type', 'text/css');

        return $response;
    }
}

==> side_menu_v1.3.3.zip: lib/Controller/CssController.php <==
<?php
/**
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace OCA\SideMenu\Controller;

use OCP\AppFramework\Controller;
use OCP\AppFramework\Http\TemplateResponse;
use OCP\AppFramework\Http\Response;
use OCP\IConfig;
use OCP\IRequest;

class CssController extends Controller
{

    /** @var \OCP\IConfig */
    protected $config;

    /**
     * @param string $appName
     * @param IRequest $request
     * @param IConfig $config
     */
    public function __construct($appName, IRequest $request, IConfig $config)
    {
        parent::__construct($appName, $request);

        $this->config = $config;
    }

    /**
     * @NoAdminRequired
     * @NoCSRFRequired
     * @PublicPage
     *
     * @return Response
     */
    public function stylesheet()
    {
        $backgroundColor = $this->config->getAppValue('side_menu', 'background-color', '#333333');
        $backgroundColorTo = $this->config->getAppValue('side_menu', 'background-color-to', $backgroundColor);

        $parameters = [
            'vars' => [
                'background-color' => $backgroundColor,
                'background-color-to' => $backgroundColorTo,
                'current-app-background-color' => $this->config->getAppValue('side_menu', 'current-app-background-color', '#444444'),
                'text-color' => $this->config->getAppValue('side_menu', 'text-color', '#FFFFFF'),
                'opener' => $this->config->getAppValue('side_menu', 'opener', 'side-menu-opener'),
            ],
            'display-logo' => (bool) $this->config->getAppValue('side_menu', 'display-logo', 1),
            'size-icon' => $this->config->getAppValue('side_menu', 'size-icon', 'normal'),
            'size-text' => $this->config->getAppValue('side_menu', 'size-text', 'normal'),
        ];

        $response = new TemplateResponse('side_menu', 'css/stylesheet', $parameters, 'blank');
        $response->addHeader('Content-Type', 'text/css');

        return $response;
    }
}
